@@ -20,7 +20,9 @@
 ;;; Code:
 
 ;; Taken from XEmacs as GNU Emacs is missing `replace-in-string' and defining
-;; it may cause clashes with other packages defining it differently 
+;; it may cause clashes with other packages defining it differently, in fact
+;; we could also call the function `replace-regexp-in-string' as Roland
+;; Winkler pointed out.
 (defun vm-replace-in-string (str regexp newtext &optional literal)
   "Replace all matches in STR for REGEXP with NEWTEXT string,
  and returns the new string.
@@ -280,6 +282,7 @@ and flexible."
 	 (setq vm-presentation-buffer-handle nil
 	       vm-presentation-buffer nil))))
 
+;;;###autoload
 (defun vm-check-for-killed-folder ()
   (and (bufferp vm-mail-buffer) (null (buffer-name vm-mail-buffer))
        (setq vm-mail-buffer nil)))
@@ -312,6 +315,15 @@ and flexible."
 	      blobarray)
     list ))
 
+(defun vm-mapvector (proc vec)
+  (let ((new-vec (make-vector (length vec) nil))
+	(i 0)
+	(n (length vec)))
+    (while (< i n)
+      (aset new-vec i (apply proc (aref vec i) nil))
+      (setq i (1+ i)))
+    new-vec))
+
 (defun vm-mapcar (function &rest lists)
   (let (arglist result)
     (while (car lists)
